==> prada_1.8.0.tar.gz: prada/R/AllGeneric.R <==
## ===========================================================================
## These are already defined as generic functions:
## ---------------------------------------------------------------------------
if(!isGeneric("colnames<-"))
  setGeneric("colnames<-",    function(x, value) standardGeneric("colnames<-"))

if(!isGeneric("colnames"))
  setGeneric("colnames",      function(x, do.NULL=TRUE, prefix="col") standardGeneric("colnames"))

if(!isGeneric("plot"))
  setGeneric("plot",          useAsDefault=plot)
## ---------------------------------------------------------------------------


## ===========================================================================
## Generic for applyGate
## ---------------------------------------------------------------------------
setGeneric("applyGate", function(data, x) standardGeneric("applyGate"))
## ---------------------------------------------------------------------------


## ===========================================================================
## Generic for gate
## ---------------------------------------------------------------------------
setGeneric("gate", function(x, ...) standardGeneric("gate"))
setGeneric("gate<-", function(object, value)
           standardGeneric("gate<-"))
## ---------------------------------------------------------------------------


## ===========================================================================
## Generic for names
## ---------------------------------------------------------------------------
setGeneric("names",    function(x) standardGeneric("names"))
setGeneric("names<-",    function(x, value) standardGeneric("names<-"))
## ---------------------------------------------------------------------------

## ===========================================================================
## Generic for drawGate
## ---------------------------------------------------------------------------
setGeneric("drawGate", function(x, ...) standardGeneric("drawGate"))
## ---------------------------------------------------------------------------

## ===========================================================================
## Generic for nrow
## ---------------------------------------------------------------------------
if(!isGeneric("nrow"))
  setGeneric("nrow", function(x) standardGeneric("nrow"))
## ---------------------------------------------------------------------------

## ===========================================================================
## Generic for nrow
## ---------------------------------------------------------------------------
if(!isGeneric("ncol"))
  setGeneric("ncol", function(x) standardGeneric("ncol"))
## ---------------------------------------------------------------------------

## ===========================================================================
## Generic for as.gateSet
## ---------------------------------------------------------------------------
setGeneric("as.gateSet", function(from) standardGeneric("as.gateSet"))
## ---------------------------------------------------------------------------

## ===========================================================================
## Generic for appendGates
## ---------------------------------------------------------------------------
setGeneric("appendGates", function(x, ...) standardGeneric("appendGates"))
## ---------------------------------------------------------------------------

==> prada_1.10.1.tar.gz: prada/R/AllGeneric.R <==
## ===========================================================================
## These are already defined as generic functions:
## ---------------------------------------------------------------------------
if(!isGeneric("colnames<-"))
  setGeneric("colnames<-",    function(x, value) standardGeneric("colnames<-"))

if(!isGeneric("colnames"))
  setGeneric("colnames",      function(x, do.NULL=TRUE, prefix="col") standardGeneric("colnames"))

if(!isGeneric("plot"))
  setGeneric("plot",          useAsDefault=plot)

if(!isGeneric("hist"))
  setGeneric("hist",          useAsDefault=hist)

if(!isGeneric("lines"))
  setGeneric("lines",          useAsDefault=lines)
## ---------------------------------------------------------------------------


## ===========================================================================
## Generic for applyGate
## ---------------------------------------------------------------------------
setGeneric("applyGate", function(data, x) standardGeneric("applyGate"))
## ---------------------------------------------------------------------------


## ===========================================================================
## Generic for gate
## ---------------------------------------------------------------------------
setGeneric("gate", function(x, ...) standardGeneric("gate"))
setGeneric("gate<-", function(object, value)
           standardGeneric("gate<-"))
## ---------------------------------------------------------------------------


## ===========================================================================
## Generic for names
## ---------------------------------------------------------------------------
#setGeneric("names",    function(x) standardGeneric("names"))
#setGeneric("names<-",    function(x, value) standardGeneric("names<-"))
## ---------------------------------------------------------------------------

## ===========================================================================
## Generic for drawGate
## ---------------------------------------------------------------------------
setGeneric("drawGate", function(x, ...) standardGeneric("drawGate"))
## ---------------------------------------------------------------------------

## ===========================================================================
## Generic for nrow
## ---------------------------------------------------------------------------
if(!isGeneric("nrow"))
  setGeneric("nrow", function(x) standardGeneric("nrow"))
## ---------------------------------------------------------------------------

## ===========================================================================
## Generic for nrow
## ---------------------------------------------------------------------------
if(!isGeneric("ncol"))
  setGeneric("ncol", function(x) standardGeneric("ncol"))
## ---------------------------------------------------------------------------

## ===========================================================================
## Generic for as.gateSet
## ---------------------------------------------------------------------------
setGeneric("as.gateSet", function(from) standardGeneric("as.gateSet"))
## ---------------------------------------------------------------------------

## ===========================================================================
## Generic for appendGates
## ---------------------------------------------------------------------------
setGeneric("appendGates", function(x, ...) standardGeneric("appendGates"))
## ---------------------------------------------------------------------------
